[![PyPI](https://img.shields.io/pypi/v/DoubleRatchet.svg)](https://pypi.org/project/DoubleRatchet/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/DoubleRatchet.svg)](https://pypi.org/project/DoubleRatchet/)
[![Build Status](https://travis-ci.org/Syndace/python-doubleratchet.svg?branch=master)](https://travis-ci.org/Syndace/python-doubleratchet)

# python-doubleratchet
#### A python implementation of the Double Ratchet algorithm.

This python library offers an implementation of the Double Ratchet algorithm as specified [here](https://signal.org/docs/specifications/doubleratchet/).

The goal is to provide a configurable and independent implementation of the algorithm, while keeping the structure close to the specification and providing recommended settings.

This library was developed as part of [python-omemo](https://github.com/Syndace/python-omemo), a pretty cool end-to-end encryption protocol.
